@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2019, Victor Ananjevsky <ananasik@gmail.com>
+ * Copyright (C) 2008-2021, Victor Ananjevsky <ananasik@gmail.com>
  */
 
 #include "yad.h"
@@ -36,20 +36,7 @@ file_confirm_overwrite (GtkWidget * dlg)
       gchar *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filechooser));
 
       if (g_file_test (filename, G_FILE_TEST_EXISTS))
-        {
-          GtkWidget *d;
-          gint r;
-          gchar *buf;
-
-          buf = g_strcompress (options.file_data.confirm_text);
-          d = gtk_message_dialog_new (GTK_WINDOW (dlg), GTK_DIALOG_DESTROY_WITH_PARENT,
-                                      GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", buf);
-          g_free (buf);
-          r = gtk_dialog_run (GTK_DIALOG (d));
-          gtk_widget_destroy (d);
-          if (r != GTK_RESPONSE_YES)
-            return FALSE;
-        }
+        return yad_confirm_dlg (GTK_WINDOW (dlg), options.file_data.confirm_text);
     }
 
   return TRUE;
