@@ -93,6 +93,9 @@ expand_action (gchar * cmd)
                   arg = g_shell_quote (buf ? buf : "");
                   g_free (buf);
                   break;
+                case YAD_FIELD_SWITCH:
+                  arg = g_strdup (print_bool_val (gtk_switch_get_state (GTK_SWITCH (g_slist_nth_data (fields, num)))));
+                  break;
                 case YAD_FIELD_SCALE:
                   arg = g_strdup_printf ("%d", (gint) gtk_range_get_value (GTK_RANGE (g_slist_nth_data (fields, num))));
                   break;
@@ -243,6 +246,10 @@ set_field_value (guint num, gchar *value)
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), get_bool_val (value));
       break;
 
+    case YAD_FIELD_SWITCH:
+      gtk_switch_set_state (GTK_SWITCH (w), get_bool_val (value));
+      break;
+
     case YAD_FIELD_COMPLETE:
       {
         GtkEntryCompletion *c;
@@ -362,9 +369,15 @@ set_field_value (guint num, gchar *value)
 
     case YAD_FIELD_TEXT:
       {
+        GtkTextIter iter;
         GtkTextBuffer *tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW (w));
         gchar *txt = g_strcompress (value);
-        gtk_text_buffer_set_text (tb, txt, -1);
+        gtk_text_buffer_set_text (tb, "", -1);
+        gtk_text_buffer_get_start_iter (tb, &iter);
+        if (options.data.no_markup)
+          gtk_text_buffer_insert (tb, &iter, txt, -1);
+        else
+          gtk_text_buffer_insert_markup (tb, &iter, txt, -1);
         g_free (txt);
         break;
       }
@@ -959,6 +972,26 @@ form_create_widget (GtkWidget * dlg)
               }
               break;
 
+           case YAD_FIELD_SWITCH:
+              {
+                e = gtk_switch_new ();
+                gtk_widget_set_name (e, "yad-form-switch");
+                if (fld->tip)
+                  {
+                    if (!options.data.no_markup)
+                      gtk_widget_set_tooltip_markup (e, fld->tip);
+                    else
+                      gtk_widget_set_tooltip_text (e, fld->tip);
+                  }
+                gtk_grid_attach (GTK_GRID (tbl), e, 1 + col * 2, row, 1, 1);
+                gtk_widget_set_hexpand (e, TRUE);
+                gtk_widget_set_halign (e, GTK_ALIGN_START); /* prevent expanding widget (make it always compact) */
+                gtk_label_set_mnemonic_widget (GTK_LABEL (l), e);
+                fields = g_slist_append (fields, e);
+                g_signal_connect_after (G_OBJECT (e), "notify::active", G_CALLBACK (field_changed_cb), GINT_TO_POINTER (i));
+              }
+              break;
+
             case YAD_FIELD_COMBO:
               e = gtk_combo_box_text_new ();
               gtk_widget_set_name (e, "yad-form-combo");
@@ -1383,6 +1416,14 @@ form_print_field (guint fn)
         g_printf ("%s%s", print_bool_val (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (g_slist_nth_data (fields, fn)))),
                   options.common_data.separator);
       break;
+    case YAD_FIELD_SWITCH:
+      if (options.common_data.quoted_output)
+        g_printf ("'%s'%s", print_bool_val (gtk_switch_get_state (GTK_SWITCH (g_slist_nth_data (fields, fn)))),
+                  options.common_data.separator);
+      else
+        g_printf ("%s%s", print_bool_val (gtk_switch_get_state (GTK_SWITCH (g_slist_nth_data (fields, fn)))),
+                  options.common_data.separator);
+      break;
     case YAD_FIELD_COMBO:
     case YAD_FIELD_COMBO_ENTRY:
       if (options.common_data.num_output && fld->type == YAD_FIELD_COMBO)
