@@ -31,6 +31,7 @@ static YadSearchBar *search_bar = NULL;
 static GString *inbuf;
 
 static gboolean is_loaded = FALSE;
+static gboolean uri_cmd = FALSE;
 
 #ifndef PATH_MAX
 #define PATH_MAX 4096
@@ -141,7 +142,7 @@ policy_cb (WebKitWebView *v, WebKitPolicyDecision *pd, WebKitPolicyDecisionType
             g_app_info_launch_default_for_uri (uri, NULL, NULL);
         }
     }
-  else if (options.data.uri_handler && options.data.uri_handler[0])
+  else if (uri_cmd && options.data.uri_handler && options.data.uri_handler[0])
     {
       gchar *v1, *v2, *cmd;
       gint status;
@@ -287,14 +288,17 @@ menu_cb (WebKitWebView *view, WebKitContextMenu *menu, GdkEvent *ev, WebKitHitTe
   WebKitContextMenuItem *mi;
   GSimpleAction *act;
 
-  mi = webkit_context_menu_item_new_separator ();
-  webkit_context_menu_prepend (menu, mi);
+  if (options.common_data.file_op)
+    {
+      mi = webkit_context_menu_item_new_separator ();
+      webkit_context_menu_prepend (menu, mi);
 
-  act = g_simple_action_new ("open", NULL);
-  g_signal_connect (G_OBJECT (act), "activate", G_CALLBACK (open_cb), d);
+      act = g_simple_action_new ("open", NULL);
+      g_signal_connect (G_OBJECT (act), "activate", G_CALLBACK (open_cb), d);
 
-  mi = webkit_context_menu_item_new_from_gaction (G_ACTION (act), _("Open URI"), NULL);
-  webkit_context_menu_prepend (menu, mi);
+      mi = webkit_context_menu_item_new_from_gaction (G_ACTION (act), _("Open URI"), NULL);
+      webkit_context_menu_prepend (menu, mi);
+    }
 
   mi = webkit_context_menu_item_new_separator ();
   webkit_context_menu_append (menu, mi);
@@ -375,7 +379,7 @@ handle_stdin (GIOChannel * ch, GIOCondition cond, gpointer d)
     case G_IO_STATUS_EOF:
       data = g_bytes_new (inbuf->str, inbuf->len);
       /*g_string_free (inbuf, TRUE); */ /* FIXME: IS THAT NEEDED ??? (and where) */
-      webkit_web_view_load_bytes (view, data, options.html_data.mime, options.html_data.encoding, NULL);
+      webkit_web_view_load_bytes (view, data, options.common_data.mime, options.html_data.encoding, NULL);
       g_bytes_unref (data);
       return FALSE;
 
@@ -426,6 +430,7 @@ html_create_widget (GtkWidget * dlg)
 {
   GtkWidget *w, *sw;
   WebKitSettings *wk_settings;
+  gchar *str;
 
   w = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
 
@@ -492,6 +497,16 @@ html_create_widget (GtkWidget * dlg)
         }
     }
 
+  /* check for user specified uri handler */
+#ifndef STANDALONE
+  str = g_settings_get_string (settings, "open-command");
+#else
+  str = g_strdup (OPEN_CMD);
+#endif
+  if (strcmp (options.data.uri_handler, str) != 0)
+    uri_cmd = TRUE;
+  g_free (str);
+
   /* load data */
   if (options.html_data.uri)
     load_uri (options.html_data.uri);
