@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2019, Victor Ananjevsky <ananasik@gmail.com>
+ * Copyright (C) 2008-2021, Victor Ananjevsky <ananasik@gmail.com>
  */
 
 #include <string.h>
@@ -493,7 +493,12 @@ cell_set_data (GtkTreeIter *it, guint num, gchar *data)
       }
     case YAD_COLUMN_IMAGE:
       {
-        GdkPixbuf *pb = get_pixbuf (data, YAD_SMALL_ICON, FALSE);
+        GdkPixbuf *pb;
+
+        if (g_file_test (data, G_FILE_TEST_EXISTS))
+          pb = get_pixbuf (data, YAD_SMALL_ICON, FALSE);
+        else
+          pb = get_pixbuf (data, YAD_SMALL_ICON, TRUE);
         if (pb)
           {
             gtk_tree_store_set (GTK_TREE_STORE (model), it, num, pb, -1);
@@ -898,9 +903,12 @@ add_row_cb (GtkMenuItem *item, gpointer data)
       gint exit;
 
       /* hide menu first */
-      gtk_menu_popdown (GTK_MENU (data));
-      while (gtk_events_pending ())
-        gtk_main_iteration ();
+      if (data)
+        {
+          gtk_menu_popdown (GTK_MENU (data));
+          while (gtk_events_pending ())
+            gtk_main_iteration ();
+        }
 
       /* run command */
       cmd = g_strdup_printf ("%s add", options.list_data.row_action);
@@ -939,9 +947,12 @@ edit_row_cb (GtkMenuItem *item, gpointer data)
       gint exit;
 
       /* hide menu first */
-      gtk_menu_popdown (GTK_MENU (data));
-      while (gtk_events_pending ())
-        gtk_main_iteration ();
+      if (data)
+        {
+          gtk_menu_popdown (GTK_MENU (data));
+          while (gtk_events_pending ())
+            gtk_main_iteration ();
+        }
 
       /* run command */
       args = get_data_as_string (&iter);
@@ -1056,6 +1067,38 @@ copy_row_cb (GtkMenuItem *item, gpointer data)
     }
 }
 
+static void
+move_row_up_cb (GtkMenuItem *item, gpointer data)
+{
+  GtkTreeIter iter;
+  GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (list_view));
+  GtkTreeSelection *sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (list_view));
+
+  if (gtk_tree_selection_get_selected (sel, NULL, &iter))
+    {
+      GtkTreeIter *prev = gtk_tree_iter_copy (&iter);
+      if (gtk_tree_model_iter_previous (model, prev))
+        gtk_tree_store_move_before (GTK_TREE_STORE (model), &iter, prev);
+      gtk_tree_iter_free (prev);
+    }
+}
+
+static void
+move_row_down_cb (GtkMenuItem *item, gpointer data)
+{
+  GtkTreeIter iter;
+  GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (list_view));
+  GtkTreeSelection *sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (list_view));
+
+  if (gtk_tree_selection_get_selected (sel, NULL, &iter))
+    {
+      GtkTreeIter *next = gtk_tree_iter_copy (&iter);
+      if (gtk_tree_model_iter_next (model, next))
+        gtk_tree_store_move_after (GTK_TREE_STORE (model), &iter, next);
+      gtk_tree_iter_free (next);
+    }
+}
+
 static gboolean
 popup_menu_cb (GtkWidget *w, GdkEventButton *ev, gpointer data)
 {
@@ -1093,7 +1136,7 @@ popup_menu_cb (GtkWidget *w, GdkEventButton *ev, gpointer data)
               item = gtk_menu_item_new_with_label (_("Edit row"));
               gtk_widget_show (item);
               gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-              g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (del_row_cb), menu);
+              g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (edit_row_cb), menu);
             }
 
           item = gtk_menu_item_new_with_label (_("Duplicate row"));
@@ -1101,6 +1144,20 @@ popup_menu_cb (GtkWidget *w, GdkEventButton *ev, gpointer data)
           gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
           g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (copy_row_cb), menu);
 
+          item = gtk_separator_menu_item_new ();
+          gtk_widget_show (item);
+          gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+          item = gtk_menu_item_new_with_label (_("Move row up"));
+          gtk_widget_show (item);
+          gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+          g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (move_row_up_cb), menu);
+
+          item = gtk_menu_item_new_with_label (_("Move row down"));
+          gtk_widget_show (item);
+          gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+          g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (move_row_down_cb), menu);
+
           gtk_widget_show (menu);
         }
       gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
@@ -1255,7 +1312,7 @@ list_create_widget (GtkWidget *dlg)
   /* create widget */
   w = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (w), GTK_SHADOW_ETCHED_IN);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (w), options.hscroll_policy, options.vscroll_policy);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (w), options.data.hscroll_policy, options.data.vscroll_policy);
 
   model = create_model ();
 
