@@ -218,6 +218,8 @@ static GOptionEntry common_options[] = {
     N_("Show hidden files in file selection dialogs"), NULL },
   { "filename", 0, 0, G_OPTION_ARG_FILENAME, &options.common_data.uri,
     N_("Set source filename"), N_("FILENAME") },
+  { "mime", 0, 0, G_OPTION_ARG_STRING, &options.common_data.mime,
+    N_("Set mime type of input data"), N_("TYPE") },
   { "vertical", 0, 0, G_OPTION_ARG_NONE, &options.common_data.vertical,
     N_("Set vertical orientation"), NULL },
   { "key", 0, 0, G_OPTION_ARG_INT, &options.common_data.key,
@@ -230,6 +232,8 @@ static GOptionEntry common_options[] = {
     N_("Make main widget scrollable"), NULL },
   { "disable-search", 0, G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &options.common_data.enable_search,
     N_("Disable search in text and html dialogs"), NULL },
+  { "file-op", 0, 0, G_OPTION_ARG_NONE, &options.common_data.file_op,
+    N_("Enable file operations"), NULL },
 #if GLIB_CHECK_VERSION(2,30,0)
   { "iec-format", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, set_size_format,
     N_("Use IEC (base 1024) units with for size values"), NULL },
@@ -305,6 +309,8 @@ static GOptionEntry color_options[] = {
     N_("Set path to palette file. Default - " RGB_FILE), N_("[FILENAME]") },
   { "expand-palette", 0, 0, G_OPTION_ARG_NONE, &options.color_data.expand_palette,
     N_("Expand user palette"), NULL },
+  { "picker", 0, 0, G_OPTION_ARG_NONE, &options.color_data.color_picker,
+    N_("Show color picker"), NULL },
   { "mode", 0, 0, G_OPTION_ARG_CALLBACK, set_color_mode,
     N_("Set output mode to MODE. Values are hex (default) or rgb"), N_("MODE") },
   { "alpha", 0, 0, G_OPTION_ARG_NONE, &options.color_data.alpha,
@@ -388,7 +394,7 @@ static GOptionEntry form_options[] = {
   { "align-buttons", 0, 0, G_OPTION_ARG_NONE, &options.form_data.align_buttons,
     N_("Align labels on button fields"), NULL },
   { "changed-action", 0, 0, G_OPTION_ARG_STRING, &options.form_data.changed_action,
-    N_("Set changed action"), "CMD" },
+    N_("Set changed action"), N_("CMD") },
   { NULL }
 };
 
@@ -402,8 +408,6 @@ static GOptionEntry html_options[] = {
     N_("Turn on browser mode"), NULL },
   { "print-uri", 0, 0, G_OPTION_ARG_NONE, &options.html_data.print_uri,
     N_("Print clicked uri to stdout"), NULL },
-  { "mime", 0, 0, G_OPTION_ARG_STRING, &options.html_data.mime,
-    N_("Set mime type of input stream data"), N_("TYPE") },
   { "encoding", 0, 0, G_OPTION_ARG_STRING, &options.html_data.encoding,
     N_("Set encoding of input stream data"), N_("ENCODING") },
   { "user-agent", 0, 0, G_OPTION_ARG_STRING, &options.html_data.user_agent,
@@ -562,6 +566,8 @@ static GOptionEntry picture_options[] = {
     N_("Set initial size (fit or orig)"), N_("TYPE") },
   { "inc", 0, 0, G_OPTION_ARG_INT, &options.picture_data.inc,
     N_("Set increment for picture scaling (default - 5)"), N_("NUMBER") },
+  { "image-changed", 0, 0, G_OPTION_ARG_STRING, &options.picture_data.change_cmd,
+    N_("Set action on image changing"), N_("CMD") },
   { NULL }
 };
 
@@ -647,6 +653,8 @@ static GOptionEntry text_options[] = {
     N_("Set justification (left, right, center or fill)"), N_("TYPE") },
   { "margins", 0, 0, G_OPTION_ARG_INT, &options.text_data.margins,
     N_("Set text margins"), N_("SIZE") },
+  { "line", 0, 0, G_OPTION_ARG_INT64, &options.text_data.line,
+    N_("Jump to specific line"), N_("NUMBER") },
   { "fore", 0, 0, G_OPTION_ARG_STRING, &options.text_data.fore,
     N_("Use specified color for text"), N_("COLOR") },
   { "back", 0, 0, G_OPTION_ARG_STRING, &options.text_data.back,
@@ -661,8 +669,6 @@ static GOptionEntry text_options[] = {
     N_("Use pango markup"), NULL },
   { "in-place", 0, 0, G_OPTION_ARG_NONE, &options.text_data.in_place,
     N_("Save file instead of print on exit"), NULL },
-  { "file-op", 0, 0, G_OPTION_ARG_NONE, &options.text_data.file_op,
-    N_("Enable file operations"), NULL },
   { "confirm-save", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, add_confirm_save,
     N_("Confirm save the file if text was changed"), N_("[TEXT]") },
   { NULL }
@@ -876,6 +882,8 @@ add_field (const gchar * option_name, const gchar * value, gpointer data, GError
         fld->type = YAD_FIELD_DATE;
       else if (strcasecmp (fstr[1], "SCL") == 0)
         fld->type = YAD_FIELD_SCALE;
+      else if (strcasecmp (fstr[1], "SW") == 0)
+        fld->type = YAD_FIELD_SWITCH;
       else if (strcasecmp (fstr[1], "BTN") == 0)
         fld->type = YAD_FIELD_BUTTON;
       else if (strcasecmp (fstr[1], "FBTN") == 0)
@@ -1631,6 +1639,7 @@ yad_options_init (void)
 
   /* Initialize common data */
   options.common_data.uri = NULL;
+  options.common_data.mime = NULL;
   options.common_data.font = NULL;
   options.common_data.separator = "|";
   options.common_data.item_separator = "!";
@@ -1664,6 +1673,7 @@ yad_options_init (void)
   options.common_data.icon_size = 0;
   options.common_data.scroll = FALSE;
   options.common_data.enable_search = TRUE;
+  options.common_data.file_op = FALSE;
 #if GLIB_CHECK_VERSION(2,30,0)
   options.common_data.size_fmt = G_FORMAT_SIZE_DEFAULT;
 #endif
@@ -1698,6 +1708,7 @@ yad_options_init (void)
   options.color_data.init_color = NULL;
   options.color_data.gtk_palette = FALSE;
   options.color_data.use_palette = FALSE;
+  options.color_data.color_picker = FALSE;
   options.color_data.expand_palette = FALSE;
   options.color_data.palette = NULL;
   options.color_data.alpha = FALSE;
@@ -1745,7 +1756,6 @@ yad_options_init (void)
   options.html_data.uri = NULL;
   options.html_data.browser = FALSE;
   options.html_data.print_uri = FALSE;
-  options.html_data.mime = NULL;
   options.html_data.encoding = NULL;
   options.html_data.user_agent = "YAD-Webkit (" VERSION ")";
   options.html_data.user_style = NULL;
@@ -1822,6 +1832,7 @@ yad_options_init (void)
   /* Initialize picture data */
   options.picture_data.size = YAD_PICTURE_ORIG;
   options.picture_data.inc = 5;
+  options.picture_data.change_cmd = NULL;
 
   /* Initialize print data */
   options.print_data.type = YAD_PRINT_TEXT;
@@ -1860,6 +1871,7 @@ yad_options_init (void)
   options.text_data.wrap = FALSE;
   options.text_data.justify = GTK_JUSTIFY_LEFT;
   options.text_data.margins = 0;
+  options.text_data.line = 0;
   options.text_data.hide_cursor = TRUE;
   options.text_data.fore = NULL;
   options.text_data.back = NULL;
@@ -1872,7 +1884,6 @@ yad_options_init (void)
 #endif
   options.text_data.formatted = FALSE;
   options.text_data.in_place = FALSE;
-  options.text_data.file_op = FALSE;
 
 #ifdef HAVE_SOURCEVIEW
   /* Initialize sourceview data */
