@@ -110,6 +110,7 @@ typedef enum {
   YAD_FIELD_COMPLETE,
   YAD_FIELD_NUM,
   YAD_FIELD_CHECK,
+  YAD_FIELD_SWITCH,
   YAD_FIELD_COMBO,
   YAD_FIELD_COMBO_ENTRY,
   YAD_FIELD_FILE,
@@ -297,6 +298,7 @@ typedef struct {
   gchar *init_color;
   gboolean gtk_palette;
   gboolean use_palette;
+  gboolean color_picker;
   gboolean expand_palette;
   gchar *palette;
   gboolean alpha;
@@ -350,7 +352,6 @@ typedef struct {
   gchar *uri;
   gboolean browser;
   gboolean print_uri;
-  gchar *mime;
   gchar *encoding;
   gchar *user_agent;
   gchar *user_style;
@@ -428,6 +429,7 @@ typedef struct {
 
 typedef struct {
   YadPictureType size;
+  gchar *change_cmd;
   gint inc;
 } YadPictureData;
 
@@ -471,6 +473,7 @@ typedef struct {
   gboolean wrap;
   GtkJustification justify;
   gint margins;
+  gulong line;
   gboolean uri;
   gboolean hide_cursor;
   gchar *uri_color;
@@ -478,7 +481,6 @@ typedef struct {
   gchar *fore;
   gchar *back;
   gboolean in_place;
-  gboolean file_op;
   gboolean confirm_save;
   gchar *confirm_text;
 } YadTextData;
@@ -505,6 +507,7 @@ typedef struct {
 
 typedef struct {
   gchar *uri;
+  gchar *mime;
   gchar *font;
   gchar *separator;
   gchar *item_separator;
@@ -525,6 +528,7 @@ typedef struct {
   gboolean hide_text;
   gint icon_size;
   gboolean enable_search;
+  gboolean file_op;
   gboolean scroll;
 #if GLIB_CHECK_VERSION(2,30,0)
   GFormatSizeFlags size_fmt;
@@ -669,6 +673,7 @@ gboolean file_confirm_overwrite (GtkWidget *dlg);
 void notebook_swallow_childs (void);
 void paned_swallow_childs (void);
 void picture_fit_to_window (void);
+void text_goto_line (void);
 
 void app_print_result (void);
 void calendar_print_result (void);
